@@ -34,8 +34,8 @@ class Entry(App):
         ("u", "show_previous_month", "Show prev month"),
         ("i", "show_next_month", "Show next month"),
         ("y", "show_current_month", "Show current month"),
-        ("ctrl+p", "focus_on_calendar", "Move to calendar"),
-        ("ctrl+o", "focus_on_sidebar", "Move to sidebar"),
+        ("e", "focus_on_calendar", "Move to calendar"),
+        ("w", "focus_on_sidebar", "Move to sidebar"),
         ("ctrl+j", "move_down_to_tag_tree", "Move down to tag tree"),
         ("ctrl+k", "move_up_to_category_tree", "Move up to category tree"),
         ("o", 'close_pop_up', "Close pop up box"),
